aio.web.page
============

Web server for the aio_ asyncio framework

.. _aio: https://github.com/phlax/aio



Build status
------------

.. image:: https://travis-ci.org/phlax/aio.web.page.svg?branch=master
	       :target: https://travis-ci.org/phlax/aio.web.page


Installation
------------
Install with:

.. code:: bash

	  pip install aio.web.page

